@@ -6,7 +6,7 @@
 #            you can capture and anlyze.
 #
 
-__version__ = "0.3"
+__version__ = "0.7"
 
 import sys
 import os
@@ -17,6 +17,7 @@ from ftg.utils.common import CommonUtils
 from ftg.formatter.graphviz_tb import GraphvizTBFormatter
 from ftg.formatter.csv import CSVFormatter
 from ftg.formatter.tsv import TSVFormatter
+from ftg.formatter.ovs_add_flow import OVSAddFlowFormatter
 
 
 if __name__ == "__main__":
@@ -33,7 +34,7 @@ if __name__ == "__main__":
         help="specify TSV dump FILE", metavar="FILE")
     p.add_option(
         '-f', '--formatter', dest='formatter',
-        help="specify formatter (graphviz, csv, tsv)", default="graphviz")
+        help="specify formatter (graphviz, csv, tsv, ovsflow)", default="graphviz")
     p.add_option(
         '-b', '--entries_per_block', dest='entries_per_block', type='int',
         help="specify number of entries in priority block", default=10)
@@ -82,6 +83,8 @@ if __name__ == "__main__":
         formatter = CSVFormatter(util)
     elif  opts.formatter == "tsv":
         formatter = TSVFormatter(util)
+    elif  opts.formatter == "ovsflow":
+        formatter = OVSAddFlowFormatter(util)
     else:
         util.error_out("specify valid formatter.")
         sys.exit(1)
